@@ -26,8 +26,6 @@ class SearchPlugin : public QObject, public Akonadi::AbstractSearchPlugin
     Q_PLUGIN_METADATA(IID "org.kde.akonadi.SearchPlugin" FILE "akonadi_search_plugin.json")
 public:
     QSet<qint64> search(const QString &query, const QVector<qint64> &collections, const QStringList &mimeTypes) override;
-private:
-    Akonadi::Search::Query fromAkonadiQuery(const QString &akonadiQuery, const QList<qint64> &collections, const QStringList &mimeTypes);
 };
 
 #endif
